package cn.net.caoyao.cpzshandset.service.bll;

import java.util.ArrayList;
import java.util.List;

import android.content.Context;
import cn.net.caoyao.cpzshandset.common.config.ConfigDBCreateService;
import cn.net.caoyao.cpzshandset.common.util.CacheGet;
import cn.net.caoyao.cpzshandset.db.presenter.ProductDal;
import cn.net.cpzslibs.prot.handset.bean.Product;

public class ProductBll {
	private ProductDal dal;
	public ProductBll(Context context) {
		ConfigDBCreateService service = new ConfigDBCreateService();
		dal = service.createProductDal(new CacheGet(), context);// 根据模式找到数据库
//		dal = new CommonProductDal(context);
	}

	/**
	 * 插入产品列表到数据库
	 * @param products
	 */
	public void insertProductList(List<Product> products){
		if (dal == null) {
			return;
		}
		dal.insertProductList(products);
	}
	/**
	 * 删除所有的产品信息
	 */
	public void deleteAllProduct(){
		if (dal == null) {
			return;
		}
		dal.deleteAllProduct();
	}
	
	/**
	 * 获取查询结果
	 * 
	 * @param msg
	 * @return
	 */
	public List<Product> getPSearch(String msg) {
		if (dal == null) {
			return new ArrayList<>();
		}
		return dal.getPSearch(msg);
	}
	/**
	 * 通过产品id获取产品信息
	 * @param id
	 * @return
	 */
	public Product queryProductById(String id){
		if (dal == null) {
			return null;
		}
		return dal.queryProductById(id);
	}
	
	/**
	 * 获取所有的产品列表信息
	 * @return
	 */
	public List<Product> queryAllProductInfo(){
		if (dal == null) {
			return new ArrayList<>();
		}
		return dal.queryAllProductInfo();
	}
	
	public List<String> queryAllImage(){
		return dal.queryAllImages();
	};
	/**
	 * 选中的次数自加1
	 * @param id
	 */
	public void updateChoiceCountById(String id){
		dal.updateChoiceCountById(id);
	}
}
